@@ -5,7 +5,7 @@ import os
 import pathlib
 import sys
 from pathlib import Path
-from typing import Union, Type, List, Dict, Tuple, Generator, Optional
+from typing import Union, Type, List, Dict, Tuple, Generator, Optional, Callable
 
 from munkres import Munkres, make_cost_matrix, Matrix  # type: ignore
 
@@ -38,10 +38,17 @@ def process_form(path_to_form) -> Generator[Dict[str, str], None, None]:
 
 
 def create_participant_list_from_path(
-    participant: Union[Type[Mentee], Type[Mentor]], path_to_data: pathlib.Path
+    participant: Union[Type[Mentee], Type[Mentor]],
+    path_to_data: pathlib.Path,
+    mapping_func: Optional[
+        Callable[[dict[str, str], str], dict[str, str]]
+    ] = lambda row, name: row,
 ):
     path_to_data = path_to_data / f"{participant.__name__.lower()}s.csv"
-    return [participant(**row) for row in process_form(path_to_data)]
+    return [
+        participant(**mapping_func(row, participant.__name__.lower()))
+        for row in process_form(path_to_data)
+    ]
 
 
 def transpose_matrix(matrix):
@@ -106,7 +113,9 @@ def process_data(
     """
     if not all_rules:
         base_rules: List[rl.AbstractRule] = [
-            rl.Disqualify(rl.Equivalent("department").evaluate),
+            rl.Disqualify(
+                lambda match: match.mentee.organisation == match.mentor.organisation
+            ),
             rl.Disqualify(
                 rl.Grade(target_diff=2, logical_operator=operator.gt).evaluate
             ),
@@ -119,8 +128,10 @@ def process_data(
             unique_rules = [
                 rl.Grade(1, operator.eq, {True: match_round.get("grade", 3), False: 0}),
                 rl.Grade(2, operator.eq, {True: match_round.get("grade", 6), False: 0}),
-                rl.Equivalent(
-                    "profession", {True: match_round.get("profession", 0), False: 0}
+                rl.Generic(
+                    {True: match_round.get("profession", 0), False: 0},
+                    lambda match: match.mentee.target_profession
+                    == match.mentor.current_profession,
                 ),
                 rl.UnmatchedBonus(match_round.get("unmatched bonus", 0)),
             ]
